@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-cookie-manager.c,v 1.9 2005/01/14 23:54:52 chpe Exp $
+ *  $Id: ephy-cookie-manager.c,v 1.10.10.2 2006/09/13 11:48:29 chpe Exp $
  */
 
 #include "config.h"
@@ -103,7 +103,7 @@ ephy_cookie_manager_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyCookieManagerIface),
 			ephy_cookie_manager_base_init,
@@ -141,7 +141,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 		      g_cclosure_marshal_VOID__BOXED,
 		      G_TYPE_NONE,
 		      1,
-		      EPHY_TYPE_COOKIE);
+		      EPHY_TYPE_COOKIE | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	/**
 	 * EphyCookieManager::cookie-changed
@@ -158,7 +158,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 		      g_cclosure_marshal_VOID__BOXED,
 		      G_TYPE_NONE,
 		      1,
-		      EPHY_TYPE_COOKIE);
+		      EPHY_TYPE_COOKIE | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	/**
 	 * EphyCookieManager::cookie-deleted
@@ -175,7 +175,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 		      g_cclosure_marshal_VOID__BOXED,
 		      G_TYPE_NONE,
 		      1,
-		      EPHY_TYPE_COOKIE);
+		      EPHY_TYPE_COOKIE | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	/**
 	 * EphyCookieManager::cookie-rejected
@@ -192,7 +192,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 		      g_cclosure_marshal_VOID__STRING,
 		      G_TYPE_NONE,
 		      1,
-		      G_TYPE_STRING);
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	/**
 	 * EphyCookieManager::cookies-cleared
