@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  *
- *  $Id: ephy-embed-factory.h,v 1.2 2004/03/17 09:02:31 marco Exp $
+ *  $Id: ephy-embed-factory.h,v 1.3.14.1 2006/09/13 11:48:29 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_FACTORY_H
@@ -27,7 +27,7 @@
 
 G_BEGIN_DECLS
 
-GObject	*ephy_embed_factory_new_object (const char *object_id);
+GObject	*ephy_embed_factory_new_object (GType type);
 
 G_END_DECLS
 
