@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.h,v 1.12 2005/01/08 19:41:46 chpe Exp $
+ *  $Id: ephy-history.h,v 1.15.4.1 2006/09/13 11:48:30 chpe Exp $
  */
 
 #ifndef EPHY_HISTORY_H
@@ -48,7 +48,9 @@ enum
 	EPHY_NODE_PAGE_PROP_HOST_ID = 7,
 	EPHY_NODE_PAGE_PROP_PRIORITY = 8,
 	EPHY_NODE_PAGE_PROP_ICON = 9,
-	EPHY_NODE_HOST_PROP_ZOOM = 10
+	EPHY_NODE_HOST_PROP_ZOOM = 10,
+	EPHY_NODE_PAGE_PROP_GECKO_FLAGS = 11,
+	EPHY_NODE_PAGE_PROP_EXTRA_FLAGS = 12
 };
 
 struct _EphyHistory
@@ -64,6 +66,10 @@ struct _EphyHistoryClass
         GObjectClass parent_class;
 
 	/* Signals */
+	gboolean (* add_page)	(EphyHistory *history,
+				 const char *url,
+				 gboolean redirect,
+				 gboolean toplevel);
 	void	(* visited)	(EphyHistory *history,
 				 const char *url);
 	void	(* cleared)	(EphyHistory *history);
@@ -88,7 +94,9 @@ EphyNode       *ephy_history_get_page           (EphyHistory *gh,
 						 const char *url);
 
 void            ephy_history_add_page           (EphyHistory *gh,
-						 const char *url);
+						 const char *url,
+						 gboolean redirect,
+						 gboolean toplevel);
 
 gboolean        ephy_history_is_page_visited    (EphyHistory *gh,
 						 const char *url);
