@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-password-manager.c,v 1.6 2004/11/02 20:56:55 chpe Exp $
+ *  $Id: ephy-password-manager.c,v 1.7.12.2 2006/09/13 11:48:30 chpe Exp $
  */
 
 #include "config.h"
@@ -113,7 +113,7 @@ ephy_password_manager_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyPasswordManagerIface),
 			ephy_password_manager_base_init,
@@ -157,37 +157,37 @@ ephy_password_manager_base_init (gpointer g_class)
 }
 
 /**
- * ephy_password_manager_add:
+ * ephy_password_manager_add_password:
  * @manager: the #EphyPasswordManager
  * @info: a #EphyPasswordInfo
  * 
  * Adds the password entry @info to the the passwords database.
  **/
 void
-ephy_password_manager_add (EphyPasswordManager *manager,
-			   EphyPasswordInfo *info)
+ephy_password_manager_add_password (EphyPasswordManager *manager,
+			            EphyPasswordInfo *info)
 {
 	EphyPasswordManagerIface *iface = EPHY_PASSWORD_MANAGER_GET_IFACE (manager);
 	iface->add (manager, info);
 }
 
 /**
- * ephy_password_manager_remove:
+ * ephy_password_manager_remove_password:
  * @manager: the #EphyPasswordManager
  * @info: a #EphyPasswordInfo
  * 
  * Removes the password entry @info from the passwords database.
  **/
 void
-ephy_password_manager_remove (EphyPasswordManager *manager,
-			      EphyPasswordInfo *info)
+ephy_password_manager_remove_password (EphyPasswordManager *manager,
+			               EphyPasswordInfo *info)
 {
 	EphyPasswordManagerIface *iface = EPHY_PASSWORD_MANAGER_GET_IFACE (manager);
 	iface->remove (manager, info);
 }
 
 /**
- * ephy_password_manager_list:
+ * ephy_password_manager_list_passwords:
  * @manager: the #EphyPasswordManager
  * 
  * Lists all password entries in the passwords database.
@@ -195,7 +195,7 @@ ephy_password_manager_remove (EphyPasswordManager *manager,
  * Return value: the list of password entries
  **/
 GList *
-ephy_password_manager_list (EphyPasswordManager *manager)
+ephy_password_manager_list_passwords(EphyPasswordManager *manager)
 {
 	EphyPasswordManagerIface *iface = EPHY_PASSWORD_MANAGER_GET_IFACE (manager);
 	return iface->list (manager);
