@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005 Christian Persch
+ *  Copyright © 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,11 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBadCertRejector.h,v 1.2 2005/10/15 10:05:08 chpe Exp $
+ *  $Id: EphyBadCertRejector.h,v 1.3.2.1 2006/09/13 11:48:34 chpe Exp $
  */
 
-#ifndef EPHY_BAD_CERT_DENIER_H
-#define EPHY_BAD_CERT_DENIER_H
+#ifndef EPHY_BAD_CERT_REJECTOR_H
+#define EPHY_BAD_CERT_REJECTOR_H
 
 #include <nsIBadCertListener.h>
 
