@@ -1,7 +1,7 @@
 /*
  *  GtkNSSKeyPairDialogs.cpp
  *
- *  Copyright (C) 2003 Crispin Flowerday <gnome@flowerday.cx>
+ *  Copyright © 2003 Crispin Flowerday <gnome@flowerday.cx>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,22 +17,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.27 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.30.2.1 2006/09/13 11:48:35 chpe Exp $
  */
 
 /*
  * This file provides Gtk implementations of the mozilla Generating Key Pair
  * dialogs.
- *
- * This implementation takes some liberties with the mozilla API. Although the
- * API requires a nsIDomWindowInternal, it only actually calls the Close()
- * function on that class. Therefore we provide a dummy class that only 
- * implements that function (it just sets a flag). 
- *
- * Periodically we check to see whether the dialog should have been closed. If
- * it should be closed, then the key generation has finished, so close the dialog
- * (using gtk_dialog_response), and return.
- *
  */
 
 #include "mozilla-config.h"
@@ -59,6 +49,7 @@
 #include "ephy-gui.h"
 
 #include "AutoJSContextStack.h"
+#include "AutoWindowModalState.h"
 #include "EphyUtils.h"
 
 #include "GtkNSSKeyPairDialogs.h"
@@ -108,6 +99,8 @@ begin_busy (GtkWidget *widget)
 	if (!GTK_WIDGET_REALIZED (widget)) gtk_widget_realize (GTK_WIDGET(widget));
 
 	gdk_window_set_cursor (GTK_WIDGET (widget)->window, cursor);
+
+	/* Eek! FIXME: AutoJSContextStack! */
 	while (gtk_events_pending ()) gtk_main_iteration ();
 }
 
@@ -139,8 +132,8 @@ generating_timeout_cb (KeyPairInfo *info)
 }
 
 
-/* void displayGeneratingKeypairInfo (in nsIInterfaceRequestor ctx, in nsIKeygenTh
-read runnable); */
+/* void displayGeneratingKeypairInfo (in nsIInterfaceRequestor ctx,
+ 				      in nsIKeygenThread runnable); */
 NS_IMETHODIMP
 GtkNSSKeyPairDialogs::DisplayGeneratingKeypairInfo (nsIInterfaceRequestor *ctx,
 						    nsIKeygenThread *runnable)
@@ -156,6 +149,8 @@ GtkNSSKeyPairDialogs::DisplayGeneratingKeypairInfo (nsIInterfaceRequestor *ctx,
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
 	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
+	AutoWindowModalState modalState (parent);
+
 	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT, (char *) NULL);
 
