@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003 Xan Lopez
+ *  Copyright © 2003 Xan Lopez
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,23 +15,24 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: mozilla-download.cpp,v 1.19.2.4 2005/04/26 12:02:28 chpe Exp $
+ * $Id: mozilla-download.cpp,v 1.25.2.2 2006/09/13 11:48:38 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "mozilla-download.h"
-#include "MozDownload.h"
+#include <nsStringAPI.h>
+
+#include <nsILocalFile.h>
+#include <nsIMIMEInfo.h>
+#include <nsIURI.h>
+#include <nsMemory.h>
 
 #include "ephy-debug.h"
 
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-#include <nsILocalFile.h>
-#include <nsMemory.h>
+#include "MozDownload.h"
+
+#include "mozilla-download.h"
 
 static void mozilla_download_class_init	(MozillaDownloadClass *klass);
 static void mozilla_download_init	(MozillaDownload *ges);
@@ -59,7 +60,7 @@ mozilla_download_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
                 {
                         sizeof (MozillaDownloadClass),
                         NULL, /* base_init */
@@ -90,7 +91,7 @@ impl_get_target (EphyDownload *download)
 
 	mozDownload->GetTargetFile (getter_AddRefs (targetFile));
 
-	nsEmbedCString tempPathStr;
+	nsCString tempPathStr;
 	targetFile->GetNativePath (tempPathStr);
 
 	return g_strdup (tempPathStr.get ());
@@ -101,7 +102,7 @@ impl_get_source (EphyDownload *download)
 {
 	nsCOMPtr<nsIURI> uri;
 	MozDownload *mozDownload;
-	nsEmbedCString spec;
+	nsCString spec;
 
 	mozDownload = MOZILLA_DOWNLOAD (download)->priv->moz_download;
 
@@ -181,24 +182,14 @@ impl_get_mime (EphyDownload *download)
 {
 	MozDownload *mozDownload;
 	nsCOMPtr<nsIMIMEInfo> mime;
-	nsEmbedCString mimeType;
+	nsCString mimeType;
 
 	mozDownload = MOZILLA_DOWNLOAD (download)->priv->moz_download;
 
 	mozDownload->GetMIMEInfo (getter_AddRefs(mime));
         if (!mime) return g_strdup ("application/octet-stream");
 
-#ifdef HAVE_GECKO_1_8
         mime->GetMIMEType(mimeType);
-#else
-	char *tmp = nsnull;
-	mime->GetMIMEType(&tmp);
-	mimeType.Assign(tmp);
-	if (tmp)
-	{
-		nsMemory::Free (tmp);
-	}
-#endif
 
 	return g_strdup (mimeType.get());
 }
@@ -301,7 +292,7 @@ mozilla_download_class_init (MozillaDownloadClass *klass)
 							       "Mozilla Download",
 							       "Mozilla Download",
 							       (GParamFlags)
-							       (G_PARAM_READWRITE |
+							       (G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							       G_PARAM_CONSTRUCT_ONLY)));
 }
 
