@@ -1,8 +1,8 @@
 /*  vim:set ts=8 noet sw=8:
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003 Robert Marcano
- *  Copyright (C) 2003, 2004, 2005, 2006 Christian Persch
- *  Copyright (C) 2005 Crispin Flowerday
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003 Robert Marcano
+ *  Copyright © 2003, 2004, 2005, 2006 Christian Persch
+ *  Copyright © 2005 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.145 2006/08/12 15:40:00 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.145.2.2 2006/09/13 11:48:38 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -143,7 +143,7 @@ mozilla_embed_single_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
                 {
                         sizeof (MozillaEmbedSingleClass),
                         NULL, /* base_init */
@@ -156,28 +156,28 @@ mozilla_embed_single_get_type (void)
                         (GInstanceInitFunc) mozilla_embed_single_init
                 };
 
-		static const GInterfaceInfo embed_single_info =
+		const GInterfaceInfo embed_single_info =
 		{
 			(GInterfaceInitFunc) ephy_embed_single_iface_init,
 			NULL,
 			NULL
 		};
 
-		static const GInterfaceInfo cookie_manager_info =
+		const GInterfaceInfo cookie_manager_info =
 		{
 			(GInterfaceInitFunc) ephy_cookie_manager_iface_init,
 			NULL,
 			NULL
 		};
 
-		static const GInterfaceInfo password_manager_info =
+		const GInterfaceInfo password_manager_info =
 		{
 			(GInterfaceInitFunc) ephy_password_manager_iface_init,
 			NULL,
 			NULL
 		};
 
-		static const GInterfaceInfo permission_manager_info =
+		const GInterfaceInfo permission_manager_info =
 		{
 			(GInterfaceInitFunc) ephy_permission_manager_iface_init,
 			NULL,
@@ -185,7 +185,7 @@ mozilla_embed_single_get_type (void)
 		};
 
 #ifdef ENABLE_CERTIFICATE_MANAGER
-		static const GInterfaceInfo certificate_manager_info =
+		const GInterfaceInfo certificate_manager_info =
 		{
 			(GInterfaceInitFunc) ephy_certificate_manager_iface_init,
 			NULL,
