@@ -2,7 +2,7 @@
 
 /* eel-gconf-extensions.c - Stuff to make GConf easier to use.
 
-   Copyright (C) 2000, 2001 Eazel, Inc.
+   Copyright © 2000, 2001 Eazel, Inc.
 
    The Gnome Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
@@ -21,7 +21,7 @@
 
    Authors: Ramiro Estrugo <ramiro@eazel.com>
 
-   $Id: eel-gconf-extensions.c,v 1.12 2004/11/02 20:57:20 chpe Exp $
+   $Id: eel-gconf-extensions.c,v 1.15.4.1 2006/09/13 11:48:44 chpe Exp $
 */
 
 #include "config.h"
@@ -29,6 +29,7 @@
 #include "eel-gconf-extensions.h"
 
 #include <glib/gi18n.h>
+
 #include <gconf/gconf-client.h>
 #include <gconf/gconf.h>
 #include <string.h>
@@ -50,18 +51,6 @@ global_client_free (void)
 GConfClient *
 eel_gconf_client_get_global (void)
 {
-	/* Initialize gconf if needed */
-	if (!gconf_is_initialized ()) {
-		char *argv[] = { "eel-preferences", NULL };
-		GError *error = NULL;
-		
-		if (!gconf_init (1, argv, &error)) {
-			if (eel_gconf_handle_error (&error)) {
-				return NULL;
-			}
-		}
-	}
-	
 	if (global_gconf_client == NULL) {
 		global_gconf_client = gconf_client_get_default ();
 		g_atexit (global_client_free);
@@ -681,47 +670,19 @@ eel_gconf_get_float (const char *key)
 static char *
 tilde_compress (const char *path)
 {
-	const char *home_dir = g_get_home_dir();
-	int         home_dir_l = strlen (home_dir);
-	int         ntilde = 0;
-	const char *scan;
-	int         path_l, result_l;
-	char       *result, *scan2;
+	const char *home;
 
-	if (path == NULL)
-		return NULL;
+	if (path == NULL) return NULL;
 
-	path_l = strlen (path);
-	for (scan = path; scan != NULL; scan++) {
-		if (path_l - (scan - path) < home_dir_l)
-			break;
-		if (strncmp (scan, home_dir, home_dir_l) == 0)
-			ntilde++;
+	home = g_get_home_dir ();
+	if (home == NULL) return g_strdup (path);
+
+	if (g_str_has_prefix (path, home))
+	{
+		return g_strconcat ("~", path + strlen (home), NULL);
 	}
-	
-	if (ntilde == 0)
-		return g_strdup (path);
-	
-	result_l = strlen (path) + ntilde - (ntilde * home_dir_l);
-	result = g_new (char, result_l + 1);
 
-	for (scan = path, scan2 = result; scan != NULL; scan2++) {
-		if (path_l - (scan - path) < home_dir_l) {
-			strcpy (scan2, scan);
-			scan2 += strlen (scan);
-			break;
-		}
-		if (strncmp (scan, home_dir, home_dir_l) == 0) {
-			*scan2 = '~';
-			scan += home_dir_l;
-		} else {
-			*scan2 = *scan;
-			scan++;
-		} 
-	}
-	*scan2 = 0;
-
-	return result;
+	return g_strdup (path);
 }
 
 void
@@ -738,3 +699,27 @@ eel_gconf_set_path (const char *key,
 	g_free (tilde_path);
 	g_free (converted);
 }
+
+void
+eel_gconf_unset_key (const char *key)
+{
+	GConfClient *client;
+	GError *error = NULL;
+
+	client = eel_gconf_client_get_global ();
+	g_return_if_fail (client != NULL);
+
+	gconf_client_unset (client, key, &error);
+	eel_gconf_handle_error (&error);
+}
+
+void
+eel_gconf_notify (const char *key)
+{
+	GConfClient *client;
+
+	client = eel_gconf_client_get_global ();
+	g_return_if_fail (client != NULL);
+
+	gconf_client_notify (client, key);
+}
