@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,13 +16,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.51 2005/05/01 19:48:05 chpe Exp $
+ *  $Id: ephy-dialog.c,v 1.54.4.2 2006/09/13 11:48:44 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-dialog.h"
-#include "ephy-glade.h"
 #include "ephy-state.h"
 #include "ephy-gui.h"
 #include "eel-gconf-extensions.h"
@@ -36,6 +35,9 @@
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtkeditable.h>
 #include <gtk/gtkentry.h>
+#include <gtk/gtksizegroup.h>
+#include <gtk/gtkdialog.h>
+#include <glade/glade-xml.h>
 
 enum
 {
@@ -113,7 +115,7 @@ ephy_dialog_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyDialogClass),
 			NULL, /* base_init */
@@ -176,7 +178,7 @@ set_value_from_pref (PropertyInfo *info, GValue *value)
 		case G_TYPE_STRING:
 			g_value_init (value, G_TYPE_STRING);
 			text = eel_gconf_get_string (info->pref);
-			g_value_take_string (value, text ? text : g_strdup (""));
+			g_value_take_string (value, text);
 			break;
 		case G_TYPE_INT:
 			g_value_init (value, G_TYPE_INT);
@@ -210,8 +212,18 @@ set_pref_from_value (PropertyInfo *info, GValue *value)
 	switch (info->data_type)
 	{
 		case G_TYPE_STRING:
-			eel_gconf_set_string (pref, g_value_get_string (value));
+		{
+			const char *string = g_value_get_string (value);
+			if (string != NULL)
+			{
+				eel_gconf_set_string (pref, string);
+			}
+			else
+			{
+				eel_gconf_unset_key (pref);
+			}
 			break;
+		}
 		case G_TYPE_INT:
 			eel_gconf_set_integer (pref, g_value_get_int (value));
 			break;
@@ -410,6 +422,11 @@ set_value_from_togglebutton (PropertyInfo *info, GValue *value)
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (info->widget));
 
+	if (info->apply_type & PT_INVERTED)
+	{
+		active = !active;
+	}
+
 	if (info->data_type == G_TYPE_BOOLEAN)
 	{
 		g_value_init (value, info->data_type);
@@ -496,6 +513,26 @@ set_editable_from_value (PropertyInfo *info, const GValue *value)
 	g_free (text);
 }
 
+static int
+strcmp_with_null (const char *key1,
+		  const char *key2)
+{
+	if (key1 == NULL && key2 == NULL)
+	{
+		return 0;
+	}
+	if (key1 == NULL)
+	{
+		return -1;
+	}
+	if (key2 == NULL)
+	{
+		return 1;
+	}
+
+	return strcmp (key1, key2);
+}
+
 static int
 get_index_from_value (const GValue *value, GList *string_enum)
 {
@@ -507,10 +544,7 @@ get_index_from_value (const GValue *value, GList *string_enum)
 	{
 		val = g_value_get_string (value);
 
-		if (val)
-		{
-			s = g_list_find_custom (string_enum, val, (GCompareFunc) strcmp);
-		}
+		s = g_list_find_custom (string_enum, val, (GCompareFunc) strcmp_with_null);
 
 		if (s)
 		{
@@ -536,7 +570,7 @@ compare_values (const GValue *a, const GValue *b)
 		ta = g_value_get_string (a);
 		tb = g_value_get_string (b);
 
-		return (ta && tb && strcmp (ta, tb) == 0);
+		return (strcmp_with_null (ta, tb) == 0);
 	}
 	else if (G_VALUE_HOLDS (a, G_TYPE_INT))
 	{
@@ -687,6 +721,11 @@ set_togglebutton_from_value (PropertyInfo *info, const GValue *value)
 
 	active = g_value_get_boolean (value);
 
+	if (info->apply_type & PT_INVERTED)
+	{
+		active = !active;
+	}
+
 	info->sane_state = TRUE;
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (info->widget), active);
@@ -738,7 +777,7 @@ set_pref_from_info_and_emit (PropertyInfo *info)
 
 	g_signal_emit (info->dialog, signals[CHANGED], g_quark_from_string (info->id), &value);
 
-	if (info->apply_type == PT_AUTOAPPLY && info->pref != NULL)
+	if ((info->apply_type & PT_AUTOAPPLY) && info->pref != NULL)
 	{
 		set_pref_from_value (info, &value);
 	}
@@ -810,7 +849,7 @@ spinbutton_changed_cb (GtkWidget *widget, PropertyInfo *info)
 {
 	GTimer *spin_timer;
 
-	if (info->apply_type != PT_AUTOAPPLY) return;
+	if ((info->apply_type & PT_AUTOAPPLY) == 0) return;
 
 	spin_timer = g_object_get_data (G_OBJECT (info->widget), "timer");
 
@@ -975,7 +1014,7 @@ save_info (gpointer key, PropertyInfo *info, EphyDialog *dialog)
 {
 	GValue value = { 0, };
 
-	if (info->pref == NULL || info->apply_type != PT_NORMAL)
+	if (info->pref == NULL || (info->apply_type & PT_NORMAL) == 0)
 	{
 		return;
 	}
@@ -1035,14 +1074,18 @@ impl_construct (EphyDialog *dialog,
 		const char *name,
 		const char *domain)
 {
+	EphyDialogPrivate *priv = dialog->priv;
 	GladeXML *gxml;
 
-	gxml = ephy_glade_widget_new
-		(file, name, &(dialog->priv->dialog), dialog, domain);
+	gxml = glade_xml_new (file, name, domain);
+	g_return_if_fail (gxml != NULL);
 
-	if (dialog->priv->name == NULL)
+	priv->dialog = glade_xml_get_widget (gxml, name);
+	g_return_if_fail (priv->dialog != NULL);
+
+	if (priv->name == NULL)
 	{
-		dialog->priv->name = g_strdup (name);
+		priv->name = g_strdup (name);
 	}
 
 	if (properties)
@@ -1050,10 +1093,8 @@ impl_construct (EphyDialog *dialog,
 		init_props (dialog, properties, gxml);
 	}
 
-	g_signal_connect_object (dialog->priv->dialog,
-				 "destroy",
-				 G_CALLBACK(dialog_destroy_cb),
-				 dialog, 0);
+	g_signal_connect_object (dialog->priv->dialog, "destroy",
+				 G_CALLBACK(dialog_destroy_cb), dialog, 0);
 
 	g_object_unref (gxml);
 }
@@ -1441,7 +1482,7 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 							      "Parent window",
 							      "Parent window",
 							      GTK_TYPE_WINDOW,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_MODAL,
@@ -1449,7 +1490,7 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 							       "Modal",
 							       "Modal dialog",
 							       FALSE,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_PERSIST_POSITION,
@@ -1457,7 +1498,7 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 							       "Persist position",
 							       "Persist dialog position",
 							       FALSE,
-							       G_PARAM_READWRITE |
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							       G_PARAM_CONSTRUCT_ONLY));
 
 	g_object_class_install_property (object_class,
@@ -1468,7 +1509,7 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 							   -1,
 							   G_MAXINT,
 							   -1,
-							   G_PARAM_READWRITE |
+							   G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							   G_PARAM_CONSTRUCT_ONLY));
 
 	g_object_class_install_property (object_class,
@@ -1479,7 +1520,7 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 							   -1,
 							   G_MAXINT,
 							   -1,
-							   G_PARAM_READWRITE |
+							   G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							   G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (EphyDialogPrivate));
