@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000, 2001, 2002 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,15 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dnd.c,v 1.15 2004/03/17 09:02:35 marco Exp $
+ *  $Id: ephy-dnd.c,v 1.18.10.1 2006/09/13 11:48:44 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-dnd.h"
-#include "ephy-string.h"
 #include "ephy-node.h"
 
 #include <gtk/gtkselection.h>
@@ -112,7 +109,7 @@ ephy_dnd_drag_data_get (GtkWidget *widget,
 
         gtk_selection_data_set (selection_data,
                                 selection_data->target,
-                                8, result->str, result->len);
+                                8, (const guchar *) result->str, result->len);
 
 	g_string_free (result, TRUE);
 
