@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-dnd.h,v 1.10.30.1 2006/09/13 11:48:44 chpe Exp $
  */
 
 #ifndef EPHY_DND_H
@@ -30,10 +32,9 @@ G_BEGIN_DECLS
 #define EPHY_DND_TEXT_TYPE              "text/plain"
 #define EPHY_DND_URL_TYPE               "_NETSCAPE_URL"
 #define EPHY_DND_TOPIC_TYPE		"ephy_topic_node"
-#define EPHY_DND_BOOKMARK_TYPE		"ephy_bookmark_node"
 
 typedef void (* EphyDragEachSelectedItemDataGet)    (const char *url,
-                                                     int x, int y, int w, int h,
+                                                     const char *title,
                                                      gpointer data);
 
 typedef void (* EphyDragEachSelectedItemIterator)   (EphyDragEachSelectedItemDataGet iteratee,
@@ -47,8 +48,6 @@ gboolean ephy_dnd_drag_data_get			(GtkWidget *widget,
 						 gpointer container_context,
 						 EphyDragEachSelectedItemIterator each_selected_item_iterator);
 
-GList   *ephy_dnd_node_list_extract_nodes	(const char *node_list);
-
 G_END_DECLS
 
 #endif
