@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2004, 2005, 2006 Christian Persch
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2004, 2005, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.48 2006/05/29 19:49:21 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.49.2.1 2006/09/13 11:48:44 chpe Exp $
  */
 
 #include "config.h"
@@ -925,6 +925,7 @@ launch_desktop_item (const char *desktop_file,
 
 gboolean
 ephy_file_launch_desktop_file (const char *filename,
+			       const char *parameter,
 			       guint32 user_time)
 {
 	GError *error = NULL;
@@ -947,7 +948,7 @@ ephy_file_launch_desktop_file (const char *filename,
 
 	if (path != NULL)
 	{
-		ret = launch_desktop_item (path, NULL, user_time, &error);
+		ret = launch_desktop_item (path, parameter, user_time, &error);
 
 		if (ret == -1 || error != NULL)
 		{
