@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002 Marco Pesenti Gritti
+ *  Copyright © 2002 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,18 +15,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.h,v 1.25 2006/05/10 18:07:01 chpe Exp $
+ *  $Id: ephy-gui.h,v 1.26.2.1 2006/09/13 11:48:44 chpe Exp $
  */
 
 #ifndef EPHY_GUI_H
 #define EPHY_GUI_H
 
-#include <gtk/gtkmenu.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreeviewcolumn.h>
-#include <gtk/gtkwindow.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkkeysyms.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtkmenu.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtktreeviewcolumn.h>
+#include <gtk/gtktreeview.h>
+#include <gtk/gtkwindow.h>
 
 G_BEGIN_DECLS
 
@@ -78,6 +79,12 @@ void		ephy_gui_window_update_user_time	 (GtkWidget *window,
 
 GtkWidget      *ephy_gui_message_dialog_get_content_box	 (GtkWidget *dialog);
 
+void		ephy_gui_message_dialog_set_wrap_mode	 (GtkMessageDialog *dialog,
+							  PangoWrapMode wrap_mode);
+
+void		ephy_gui_connect_checkbutton_to_gconf	 (GtkWidget *widget,
+							  const char *pref);
+
 G_END_DECLS
 
 #endif
