@@ -1,5 +1,5 @@
 /* 
- *  Copyright (C) 2002 Olivier Martin <omartin@ifrance.com>
+ *  Copyright © 2002 Olivier Martin <omartin@ifrance.com>
  *            (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-filter.c,v 1.9 2004/12/19 11:00:50 chpe Exp $
+ *  $Id: ephy-node-filter.c,v 1.10.12.2 2006/09/13 11:48:44 chpe Exp $
  */
 
 #include "config.h"
@@ -41,12 +41,12 @@ enum
 
 #define EPHY_NODE_FILTER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NODE_FILTER, EphyNodeFilterPrivate))
 
-struct EphyNodeFilterPrivate
+struct _EphyNodeFilterPrivate
 {
 	GPtrArray *levels;
 };
 
-struct EphyNodeFilterExpression
+struct _EphyNodeFilterExpression
 {
 	EphyNodeFilterExpressionType type;
 
@@ -83,7 +83,7 @@ ephy_node_filter_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyNodeFilterClass),
 			NULL,
