@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002 Marco Pesenti Gritti
+ *  Copyright © 2002 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-string.h,v 1.14 2005/10/11 13:12:36 chpe Exp $
+ *  $Id: ephy-string.h,v 1.16.2.1 2006/09/13 11:48:44 chpe Exp $
  */
 
 #ifndef EPHY_STRING_H
 #define EPHY_STRING_H
 
 #include <glib.h>
+#include <glib-object.h>
 
 G_BEGIN_DECLS
 
@@ -33,6 +34,21 @@ char	 *ephy_string_blank_chr	(char *source);
 char	 *ephy_string_shorten	(char *str,
 				 gsize target_length);
 
+char	 *ephy_string_collate_key_for_domain	(const char *host,
+						 gssize len);
+
+guint	  ephy_string_flags_from_string	(GType type,
+					 const char *flags_string);
+
+char     *ephy_string_flags_to_string	(GType type,
+					 guint flags_value);
+
+guint	  ephy_string_enum_from_string	(GType type,
+					 const char *enum_string);
+
+char     *ephy_string_enum_to_string	(GType type,
+					 guint enum_value);
+
 G_END_DECLS
 
 #endif
