@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-zoom-control.c,v 1.15 2005/01/14 18:08:29 chpe Exp $
+ *  $Id: ephy-zoom-control.c,v 1.17.2.2 2006/09/13 11:48:49 chpe Exp $
  */
 
 #include "config.h"
@@ -66,7 +66,7 @@ ephy_zoom_control_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 			{
 				sizeof (EphyZoomControlClass),
 				NULL, /* base_init */
@@ -137,8 +137,7 @@ ephy_zoom_control_init (EphyZoomControl *control)
 
 	p->combo = combo;
 	gtk_combo_box_set_focus_on_click (GTK_COMBO_BOX (p->combo), FALSE);
-	g_object_ref (combo);
-	gtk_object_sink (GTK_OBJECT (combo));
+	g_object_ref_sink (combo);
 	gtk_widget_show (GTK_WIDGET (combo));
 
 	i = ephy_zoom_get_zoom_level_index (p->zoom);
@@ -274,7 +273,7 @@ ephy_zoom_control_class_init (EphyZoomControlClass *klass)
 							     ZOOM_MINIMAL,
 							     ZOOM_MAXIMAL,
 							     1.0,
-							     G_PARAM_READWRITE));
+							     G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	signals[ZOOM_TO_LEVEL_SIGNAL] =
 		g_signal_new ("zoom_to_level",
