@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.79 2006/01/25 19:39:42 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.81.4.2 2006/09/13 11:49:01 chpe Exp $
  */
 
 #include "config.h"
@@ -342,7 +342,6 @@ button_press_cb (GtkWidget *button,
 		if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
 		{
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-			button_toggled_cb (button, action);
 
 			return TRUE;
 		}
@@ -563,7 +562,7 @@ ephy_topic_action_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo type_info =
+		const GTypeInfo type_info =
 		{
 			sizeof (EphyTopicActionClass),
 			(GBaseInitFunc) NULL,
@@ -584,18 +583,12 @@ ephy_topic_action_get_type (void)
 	return type;
 }
 
-char *
-ephy_topic_action_name (EphyNode *node)
-{
-	return g_strdup_printf("Tpc%u", ephy_node_get_id (node));
-}
-
 GtkAction *
 ephy_topic_action_new (EphyNode *node,
 		       GtkUIManager *manager,
-		       char *name)
+		       const char *name)
 {
-	g_return_val_if_fail (name, NULL);
+	g_assert (name != NULL);
 
 	return GTK_ACTION (g_object_new (EPHY_TYPE_TOPIC_ACTION,
 					 "name", name,
