@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002  Ricardo Fernández Pascual
- *  Copyright (C) 2003  Marco Pesenti Gritti
- *  Copyright (C) 2003  Christian Persch
+ *  Copyright © 2002  Ricardo Fernández Pascual
+ *  Copyright © 2003  Marco Pesenti Gritti
+ *  Copyright © 2003  Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-menu.c,v 1.37 2006/03/02 21:23:34 jframeau Exp $
+ *  $Id: ephy-encoding-menu.c,v 1.37.4.2 2006/09/13 11:48:50 chpe Exp $
  */
 
 #include "config.h"
@@ -71,7 +71,7 @@ ephy_encoding_menu_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyEncodingMenuClass),
 			NULL,
