@@ -1,6 +1,6 @@
 /* 
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003-2005 Christian Persch
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003-2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-fullscreen-popup.c,v 1.9 2006/03/28 20:06:55 chpe Exp $
+ *  $Id: ephy-fullscreen-popup.c,v 1.9.2.2 2006/09/13 11:48:50 chpe Exp $
  */
 
 #include "config.h"
@@ -434,7 +434,7 @@ ephy_fullscreen_popup_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyFullscreenPopupClass),
 			NULL,
