@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 David Bordoley
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 David Bordoley
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-go-action.c,v 1.12 2005/01/06 00:48:03 chpe Exp $
+ *  $Id: ephy-go-action.c,v 1.13.4.2 2006/09/13 11:48:50 chpe Exp $
  */
 
 #include "config.h"
@@ -39,7 +39,7 @@ ephy_go_action_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo type_info =
+		const GTypeInfo type_info =
 		{
 			sizeof (EphyGoActionClass),
 			(GBaseInitFunc) NULL,
@@ -52,7 +52,7 @@ ephy_go_action_get_type (void)
 			(GInstanceInitFunc) NULL,
 		};
 
-		type = g_type_register_static (GTK_TYPE_ACTION,
+		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
 					       "EphyGoAction",
 					       &type_info, 0);
 	}
