@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Christophe Fergeau
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2002 Christophe Fergeau
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.91 2006/05/11 12:48:32 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.92.2.2 2006/09/13 11:48:52 chpe Exp $
  */
 
 #include "config.h"
@@ -109,7 +109,7 @@ ephy_notebook_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 			{
 				sizeof (EphyNotebookClass),
 				NULL, /* base_init */
@@ -122,7 +122,7 @@ ephy_notebook_get_type (void)
 				(GInstanceInitFunc) ephy_notebook_init
 			};
 
-		static const GInterfaceInfo link_info =
+		const GInterfaceInfo link_info =
 		{
 			NULL,
 			NULL,
@@ -727,6 +727,14 @@ ephy_notebook_set_show_tabs (EphyNotebook *nb, gboolean show_tabs)
 	update_tabs_visibility (nb, FALSE);
 }
 
+GList *
+ephy_notebook_get_focused_pages (EphyNotebook *nb)
+{
+	g_return_val_if_fail (EPHY_IS_NOTEBOOK (nb), NULL);
+
+	return nb->priv->focused_pages;
+}
+
 static int
 ephy_notebook_insert_page (GtkNotebook *gnotebook,
 			   GtkWidget *tab_widget,
