@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
- *  Copyright (C) 2004, 2005 Adam Hooper
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
+ *  Copyright © 2004, 2005 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-python-extension.c,v 1.2 2005/07/29 19:53:46 chpe Exp $
+ *  $Id: ephy-python-extension.c,v 1.3.4.2 2006/09/13 11:48:52 chpe Exp $
  */
 
 #include "Python.h"
@@ -330,7 +330,7 @@ ephy_python_extension_class_init (EphyPythonExtensionClass *klass)
 					      "Filename",
 					      "Filename",
 					      NULL,
-					      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+					      G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (EphyPythonExtensionPrivate));
 }
@@ -342,7 +342,7 @@ ephy_python_extension_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyPythonExtensionClass),
 			NULL, /* base_init */
@@ -354,7 +354,7 @@ ephy_python_extension_get_type (void)
 			0, /* n_preallocs */
 			(GInstanceInitFunc) ephy_python_extension_init
 		};
-		static const GInterfaceInfo extension_info =
+		const GInterfaceInfo extension_info =
 		{
 			(GInterfaceInitFunc) ephy_python_extension_iface_init,
 			NULL,
