@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.h,v 1.7 2005/01/21 04:08:38 adamh Exp $
+ *  $Id: ephy-statusbar.h,v 1.10.2.1 2006/09/13 11:48:53 chpe Exp $
  */
 
 #ifndef EPHY_STATUSBAR_H
@@ -55,12 +55,22 @@ struct _EphyStatusbar
 struct _EphyStatusbarClass
 {
         GtkStatusbarClass parent_class;
+
+	/* Signals */
+	void (* lock_clicked)	(EphyStatusbar *statusbar);
 };
 
 GType         ephy_statusbar_get_type			(void);
 
 GtkWidget    *ephy_statusbar_new			(void);
 
+GtkTooltips  *ephy_statusbar_get_tooltips		(EphyStatusbar *statusbar);
+
+GtkWidget    *ephy_statusbar_get_security_frame		(EphyStatusbar *statusbar);
+
+void	      ephy_statusbar_set_caret_mode		(EphyStatusbar *statusbar,
+							 gboolean enabled);
+
 void          ephy_statusbar_set_security_state		(EphyStatusbar *statusbar,
 							 const char *stock_id,
 							 const char *tooltip);
