@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.h,v 1.29.4.1 2005/09/28 13:36:17 chpe Exp $
+ *  $Id: ephy-tab.h,v 1.31.2.1 2006/09/13 11:48:53 chpe Exp $
  */
 
 #ifndef EPHY_TAB_H
@@ -121,6 +121,9 @@ gboolean		ephy_tab_get_visibility		(EphyTab *tab);
 
 float			ephy_tab_get_zoom		(EphyTab *tab);
 
+/* private */
+guint		       _ephy_tab_get_id			(EphyTab *tab);
+
 G_END_DECLS
 
 #endif
