@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.h,v 1.39 2005/08/03 20:29:26 chpe Exp $
+ *  $Id: ephy-window.h,v 1.41.4.1 2006/09/13 11:48:54 chpe Exp $
  */
 
 #ifndef EPHY_WINDOW_H
@@ -43,15 +43,15 @@ typedef struct _EphyWindowPrivate	EphyWindowPrivate;
 
 struct _EphyWindow
 {
-        GtkWindow parent;
+	GtkWindow parent;
 
 	/*< private >*/
-        EphyWindowPrivate *priv;
+	EphyWindowPrivate *priv;
 };
 
 struct _EphyWindowClass
 {
-        GtkWindowClass parent_class;
+	GtkWindowClass parent_class;
 };
 
 GType		  ephy_window_get_type		  (void);
@@ -68,8 +68,6 @@ GObject		 *ephy_window_get_ui_manager	  (EphyWindow *window);
 
 GtkWidget	 *ephy_window_get_toolbar	  (EphyWindow *window);
 
-GtkWidget	 *ephy_window_get_bookmarksbar	  (EphyWindow *window);
-
 GtkWidget	 *ephy_window_get_notebook	  (EphyWindow *window);
 
 GtkWidget        *ephy_window_get_find_toolbar    (EphyWindow *window);
@@ -107,6 +105,11 @@ gboolean	  ephy_window_get_is_print_preview(EphyWindow *window);
 
 EphyEmbedEvent	 *ephy_window_get_context_event	  (EphyWindow *window);
 
+void		 _ephy_window_set_context_event	  (EphyWindow *window,
+						   EphyEmbedEvent *event);
+
+void		 _ephy_window_unset_context_event (EphyWindow *window);
+
 G_END_DECLS
 
 #endif
